<?php

namespace Litecms\VideoArchive\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Repository\Filter\RequestFilter;
use Litecms\VideoArchive\Forms\VideoArchive as VideoArchiveForm;
use Litecms\VideoArchive\Http\Requests\VideoArchiveRequest;
use Litecms\VideoArchive\Interfaces\VideoArchiveRepositoryInterface;
use Litecms\VideoArchive\Repositories\Eloquent\Filters\VideoArchiveResourceFilter;
use Litecms\VideoArchive\Repositories\Eloquent\Presenters\VideoArchiveListPresenter;

/**
 * Resource controller class for video_archive.
 */
class VideoArchiveResourceController extends BaseController
{

    /**
     * Initialize video_archive resource controller.
     *
     *
     * @return null
     */
    public function __construct(VideoArchiveRepositoryInterface $video_archive)
    {
        parent::__construct();
        $this->form = VideoArchiveForm::setAttributes()->toArray();
        $this->modules = $this->modules(config('litecms.video_archive.modules'), 'video_archive', guard_url('video_archive'));
        $this->repository = $video_archive;
    }

    /**
     * Display a list of video_archive.
     *
     * @return Response
     */
    public function index(VideoArchiveRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(VideoArchiveResourceFilter::class)
            ->setPresenter(VideoArchiveListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('video_archive::video_archive.names'))
            ->view('video_archive::video_archive.index')
            ->data(compact('data', 'meta', 'links', 'modules', 'form'))
            ->output();
    }

    /**
     * Display video_archive.
     *
     * @param Request $request
     * @param Model   $video_archive
     *
     * @return Response
     */
    public function show(VideoArchiveRequest $request, VideoArchiveRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('video_archive::video_archive.name'))
            ->data(compact('data', 'form', 'modules', 'form'))
            ->view('video_archive::video_archive.show')
            ->output();
    }

    /**
     * Show the form for creating a new video_archive.
     *
     * @param Request $request
     *x
     * @return Response
     */
    public function create(VideoArchiveRequest $request, VideoArchiveRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('video_archive::video_archive.name'))
            ->view('video_archive::video_archive.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Create new video_archive.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(VideoArchiveRequest $request, VideoArchiveRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $repository->create($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.created', ['Module' => trans('video_archive::video_archive.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('video_archive/video_archive/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/video_archive/video_archive'))
                ->redirect();
        }

    }

    /**
     * Show video_archive for editing.
     *
     * @param Request $request
     * @param Model   $video_archive
     *
     * @return Response
     */
    public function edit(VideoArchiveRequest $request, VideoArchiveRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('video_archive::video_archive.name'))
            ->view('video_archive::video_archive.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Update the video_archive.
     *
     * @param Request $request
     * @param Model   $video_archive
     *
     * @return Response
     */
    public function update(VideoArchiveRequest $request, VideoArchiveRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $repository->update($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('video_archive::video_archive.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('video_archive/video_archive/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('video_archive/video_archive/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the video_archive.
     *
     * @param Model   $video_archive
     *
     * @return Response
     */
    public function destroy(VideoArchiveRequest $request, VideoArchiveRepositoryInterface $repository)
    {
        try {
            $repository->delete();
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('video_archive::video_archive.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('video_archive/video_archive/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('video_archive/video_archive/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }
}
